@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require 'rspec/expectations'
 require 'shellwords'
 
 require 'aruba/version'
-require 'aruba/extensions/string/strip'
 
 require 'aruba/platform'
 require 'aruba/api/core'
